@@ -9,46 +9,49 @@ function squirrelmail_plugin_init_show_user_and_ip() {
    $squirrelmail_plugin_hooks['options_display_inside']['show_user_and_ip'] = 'left_option';
    $squirrelmail_plugin_hooks['options_display_save']['show_user_and_ip'] = 'left_option_save';
    $squirrelmail_plugin_hooks['logout']['show_user_and_ip'] = 'reset_first_login';
-
 }
 
 function show_user_and_ip_version() {
     return '2.2.2';
 }
 
+if (!defined('SM_PATH'))  {
+    define('SM_PATH','../../');
+}
+
 function show_user_and_ip()
 {
-  include_once('../plugins/show_user_and_ip/functions.php');
+  include_once(SM_PATH . 'plugins/show_user_and_ip/functions.php');
   show_ui();
 }
 
 function last_date_and_ip_load() {
-  include_once('../plugins/show_user_and_ip/functions.php');
+  include_once(SM_PATH . 'plugins/show_user_and_ip/functions.php');
   last_load();
 }
 
 function show_last_date_and_ip() {
-  include_once('../plugins/show_user_and_ip/functions.php');
+  include_once(SM_PATH . 'plugins/show_user_and_ip/functions.php');
   show_last();
 }
 
 function left_option() {
-  include_once('../plugins/show_user_and_ip/functions.php');
+  include_once(SM_PATH . 'plugins/show_user_and_ip/functions.php');
   left_opt();
 }
 
 function left_option_save() {
-  include_once('../plugins/show_user_and_ip/functions.php');
+  include_once(SM_PATH . 'plugins/show_user_and_ip/functions.php');
   left_opt_save();
 }
 
 function last_date_and_ip_save() {
-  include_once('../plugins/show_user_and_ip/functions.php');
+  include_once(SM_PATH . 'plugins/show_user_and_ip/functions.php');
   last_save();
 }
 
 function reset_first_login() {
-  include_once('../plugins/show_user_and_ip/functions.php');
+  include_once(SM_PATH . 'plugins/show_user_and_ip/functions.php');
   reset_fl();
 }
 
